@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Redmine - project management software
-# Copyright (C) 2006-2023  Jean-Philippe Lang
+# Copyright (C) 2006-  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -67,24 +67,24 @@ class IssuesController < ApplicationController
           end
         end
         format.atom do
-          @issues = @query.issues(:limit => Setting.feeds_limit.to_i)
-          render_feed(@issues,
+          issues = @query.issues(:limit => Setting.feeds_limit.to_i)
+          render_feed(issues,
                       :title => "#{@project || Setting.app_title}: #{l(:label_issue_plural)}")
         end
         format.csv do
-          @issues = @query.issues(:limit => Setting.issues_export_limit.to_i)
-          send_data(query_to_csv(@issues, @query, params[:csv]),
-                    :type => 'text/csv; header=present', :filename => 'issues.csv')
+          issues = @query.issues(:limit => Setting.issues_export_limit.to_i)
+          send_data(query_to_csv(issues, @query, params[:csv]),
+                    :type => 'text/csv; header=present', :filename => "#{filename_for_export(@query, 'issues')}.csv")
         end
         format.pdf do
           @issues = @query.issues(:limit => Setting.issues_export_limit.to_i)
-          send_file_headers! :type => 'application/pdf', :filename => 'issues.pdf'
+          send_file_headers! :type => 'application/pdf', :filename => "#{filename_for_export(@query, 'issues')}.pdf"
         end
       end
     else
       respond_to do |format|
         format.html {render :layout => !request.xhr?}
-        format.any(:atom, :csv, :pdf) {head 422}
+        format.any(:atom, :csv, :pdf) {head :unprocessable_content}
         format.api {render_validation_errors(@query)}
       end
     end
@@ -93,14 +93,16 @@ class IssuesController < ApplicationController
   end
 
   def show
-    @journals = @issue.visible_journals_with_index
-    @has_changesets = @issue.changesets.visible.preload(:repository, :user).exists?
-    @relations =
-      @issue.relations.
-        select do |r|
-          r.other_issue(@issue) && r.other_issue(@issue).visible?
-        end
-    @journals.reverse! if User.current.wants_comments_in_reverse_order?
+    if !api_request? || include_in_api_response?('journals')
+      @journals = @issue.visible_journals_with_index
+      @journals.reverse! if User.current.wants_comments_in_reverse_order?
+    end
+    if !api_request? || include_in_api_response?('relations')
+      @relations = @issue.relations.select {|r| r.other_issue(@issue)&.visible?}
+    end
+    if !api_request? || include_in_api_response?('allowed_statuses')
+      @allowed_statuses = @issue.new_statuses_allowed_to(User.current)
+    end
 
     if User.current.allowed_to?(:view_time_entries, @project)
       Issue.load_visible_spent_hours([@issue])
@@ -109,18 +111,24 @@ class IssuesController < ApplicationController
 
     respond_to do |format|
       format.html do
-        @allowed_statuses = @issue.new_statuses_allowed_to(User.current)
         @priorities = IssuePriority.active
-        @time_entry = TimeEntry.new(:issue => @issue, :project => @issue.project)
-        @time_entries = @issue.time_entries.visible.preload(:activity, :user)
+        if @project.module_enabled?(:time_tracking)
+          @time_entry = TimeEntry.new(:issue => @issue, :project => @issue.project)
+          @time_entries = @issue.time_entries.visible.preload(:activity, :user)
+        else
+          @time_entry = nil
+          @time_entries = []
+        end
         @relation = IssueRelation.new
+        @has_changesets = @issue.changesets.visible.preload(:repository, :user).exists?
         retrieve_previous_and_next_issue_ids
         render :template => 'issues/show'
       end
       format.api do
-        @allowed_statuses = @issue.new_statuses_allowed_to(User.current)
-        @changesets = @issue.changesets.visible.preload(:repository, :user).to_a
-        @changesets.reverse! if User.current.wants_comments_in_reverse_order?
+        if include_in_api_response?('changesets')
+          @changesets = @issue.changesets.visible.preload(:repository, :user).to_a
+          @changesets.reverse! if User.current.wants_comments_in_reverse_order?
+        end
       end
       format.atom do
         render :template => 'journals/index', :layout => false,
@@ -221,9 +229,8 @@ class IssuesController < ApplicationController
       end
       respond_to do |format|
         format.html do
-          redirect_back_or_default(
-            issue_path(@issue, previous_and_next_issue_ids_params)
-          )
+          redirect_back_or_default issue_path(@issue),
+            flash: { previous_and_next_issue_ids: previous_and_next_issue_ids_params }
         end
         format.api  {render_api_ok}
       end
@@ -325,7 +332,8 @@ class IssuesController < ApplicationController
     @versions = target_projects.map {|p| p.shared_versions.open}.reduce(:&)
     @categories = target_projects.map {|p| p.issue_categories}.reduce(:&)
     if @copy
-      @attachments_present = @issues.detect {|i| i.attachments.any?}.present?
+      @attachments_present = @issues.detect {|i| i.attachments.any?}.present? &&
+                               (Setting.copy_attachments_on_issue_copy == 'ask')
       @subtasks_present = @issues.detect {|i| !i.leaf?}.present?
       @watchers_present = User.current.allowed_to?(:add_issue_watchers, @projects) &&
                             Watcher.where(:watchable_type => 'Issue',
@@ -344,7 +352,6 @@ class IssuesController < ApplicationController
 
     attributes = parse_params_for_bulk_update(params[:issue])
     copy_subtasks = (params[:copy_subtasks] == '1')
-    copy_attachments = (params[:copy_attachments] == '1')
     copy_watchers = (params[:copy_watchers] == '1')
 
     if @copy
@@ -383,7 +390,7 @@ class IssuesController < ApplicationController
       if @copy
         issue = orig_issue.copy(
           {},
-          :attachments => copy_attachments,
+          :attachments => copy_attachments?(params[:copy_attachments]),
           :subtasks => copy_subtasks,
           :watchers => copy_watchers,
           :link => link_copy?(params[:link_copy])
@@ -499,8 +506,9 @@ class IssuesController < ApplicationController
       return
     end
     if !params[:set_filter] && use_session && session[:issue_query]
+      # Don't apply the default query if a valid query id is set in the session
       query_id, project_id = session[:issue_query].values_at(:id, :project_id)
-      return if IssueQuery.where(id: query_id).exists? && project_id == @project&.id
+      return if query_id && project_id == @project&.id && IssueQuery.exists?(id: query_id)
     end
     if default_query = IssueQuery.default(project: @project)
       params[:query_id] = default_query.id
@@ -508,11 +516,14 @@ class IssuesController < ApplicationController
   end
 
   def retrieve_previous_and_next_issue_ids
-    if params[:prev_issue_id].present? || params[:next_issue_id].present?
-      @prev_issue_id = params[:prev_issue_id].presence.try(:to_i)
-      @next_issue_id = params[:next_issue_id].presence.try(:to_i)
-      @issue_position = params[:issue_position].presence.try(:to_i)
-      @issue_count = params[:issue_count].presence.try(:to_i)
+    if flash.key?(:previous_and_next_issue_ids)
+      flash[:previous_and_next_issue_ids].then do |info|
+        @prev_issue_id = info[:prev_issue_id].presence.try(:to_i)
+        @next_issue_id = info[:next_issue_id].presence.try(:to_i)
+        @issue_position = info[:issue_position].presence.try(:to_i)
+        @issue_count = info[:issue_count].presence.try(:to_i)
+      end
+      flash.delete(:previous_and_next_issue_ids)
     else
       retrieve_query_from_session
       if @query
@@ -520,7 +531,7 @@ class IssuesController < ApplicationController
         limit = 500
         issue_ids = @query.issue_ids(:limit => (limit + 1))
         if (idx = issue_ids.index(@issue.id)) && idx < limit
-          if issue_ids.size < 500
+          if issue_ids.size < limit
             @issue_position = idx + 1
             @issue_count = issue_ids.size
           end
@@ -589,7 +600,7 @@ class IssuesController < ApplicationController
         end
 
         @link_copy = link_copy?(params[:link_copy]) || request.get?
-        @copy_attachments = params[:copy_attachments].present? || request.get?
+        @copy_attachments = copy_attachments?(params[:copy_attachments]) || request.get?
         @copy_subtasks = params[:copy_subtasks].present? || request.get?
         @copy_watchers = User.current.allowed_to?(:add_issue_watchers, @project)
         @issue.copy_from(@copy_from, :attachments => @copy_attachments,
@@ -692,15 +703,27 @@ class IssuesController < ApplicationController
     end
   end
 
+  # Returns true if the attachments should be copied
+  # from the original issue
+  def copy_attachments?(param)
+    case Setting.copy_attachments_on_issue_copy
+    when 'yes'
+      true
+    when 'no'
+      false
+    when 'ask'
+      param == '1'
+    end
+  end
+
   # Redirects user after a successful issue creation
   def redirect_after_create
     if params[:continue]
       url_params = {}
-      url_params[:issue] =
-        {
-          :tracker_id => @issue.tracker,
-          :parent_issue_id => @issue.parent_issue_id
-        }.reject {|k, v| v.nil?}
+      url_params[:issue] = {
+        :tracker_id => @issue.tracker,
+        :parent_issue_id => @issue.parent_issue_id
+      }.compact
       url_params[:back_url] = params[:back_url].presence
 
       if params[:project_id]
